==> nextcloud-app-mail-0.6.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/he.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "דואר",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message in {folderName} \nfrom {from}_::_%n new messages in {folderName} \nfrom {from}_" : ["%n הודעה חדשה ב- {folderName} \nמ- {from}","%n הודעות חדשות ב- {folderName} \nמ- {from}"],
    "Error while loading the accounts." : "שגיאה בזמן העלאת החשבונות.",
    "Error while loading the selected account." : "שגיאה בזמן טעינת החשבון הנבחר.",
    "Error while loading messages." : "שגיאה בזמן העלאת הודעות.",
    "Error while loading the selected message." : "שגיאה בזמן טעינת ההודעה שנבחרה.",
    "Forwarded message" : "הודעה שקודמה",
    "Choose a folder to store the attachment in" : "יש לבחור תיקייה לשמירת הקובץ המצורף",
    "Attachments saved to Files." : "שבצים מצורפים נשמרו לקטגוריית קבצים.",
    "Attachment saved to Files." : "קובץ מצורף נשמר לקטגוריית קבצים.",
    "Error while saving attachments to Files." : "שגיאה בזמן שמירת קבצים מצורפים לקטגוריית קבצים.",
    "Error while saving attachment to Files." : "שגיאה בזמן שמירת קובץ מצורף לקטגוריית קבצים.",
    "Message flag could not be set." : "לא ניתן היה להגדיר דגל להודעה",
    "Invalid account" : "חשבון לא חוקי",
    "Invalid folder" : "תיקייה לא חוקית",
    "Unknown error" : "שגיאה בלתי ידועה",
    "Error while creating an account: " : "שגיאה בזמן יצירת חשבון:",
    "Show all folders" : "הצגת כל התיקיות",
    "Collapse folders" : "קיווץ תיקיות",
    "Error while deleting account." : "שגיאה בזמן מחיקת חשבון.",
    "Choose a file to add as attachment" : "בחירת קובץ להוספה כקובץ מצורף",
    "Reply" : "תגובה",
    "Send" : "שליחה",
    "Sending …" : "שולח...",
    "Message sent!" : "הודעה נשלחה!",
    "Server error" : "שגיאת שרת",
    "Opening HTML drafts is not supported yet." : "פתיחת טיוטות HTML לא נתמך עדיין.",
    "Draft saved!" : "טיוטה נשמרה!",
    "you" : "את/ה",
    "Send message to {email}" : "שליחת הודעה אל {email}",
    "No writable calendars found" : "לא נמצאו יומנים ברי כתיבה",
    "Error while importing the calendar event" : "שגיאה בזמן יבוא של אירוע היומן",
    "Error while downloading calendar event" : "שגיאה בזמן הורדת אירוע יומן",
    "Error while deleting message." : "שגיאה בזמן מחיקת הודעה.",
    "Connecting" : "מתחבר",
    "Connect" : "התחברות",
    "Inbox" : "דואר נכנס",
    "Sent" : "נשלח",
    "Drafts" : "טיוטות",
    "Archive" : "ארכיב",
    "Trash" : "פח אשפה",
    "Junk" : "דואר זבל",
    "All" : "הכל",
    "Favorites" : "מועדפים",
    "Creating account failed: " : "יצירת חשבון נכשלה:",
    "Auto detect failed. Please use manual mode." : "איתור אוטומטי נכשל. יש להשתמש במצב ידני.",
    "Delete permanently" : "מחיקה לצמיתות",
    "& others" : "& אחרים",
    "All inboxes" : "כל תיבות דואר נכנס",
    "Error loading message" : "שגיאה בהעלאת הודעה",
    "Redirect" : "הפנייה",
    "The link leads to %s" : "הקישור מוביל אל %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "אם אינך רוצה לבקר בדף זה, ניתן לחזור אל <a href=\"%s\">הדואר</a>.",
    "Continue to %s" : "ממשיך אל %s"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-mail-0.7.10-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/he.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "דואר",
    "Error while loading the accounts." : "שגיאה בזמן העלאת החשבונות.",
    "Error while loading the selected account." : "שגיאה בזמן טעינת החשבון הנבחר.",
    "Error while deleting message." : "שגיאה בזמן מחיקת הודעה.",
    "Forwarded message" : "הודעה שקודמה",
    "Choose a folder to store the attachment in" : "יש לבחור תיקייה לשמירת הקובץ המצורף",
    "Attachments saved to Files." : "שבצים מצורפים נשמרו לקטגוריית קבצים.",
    "Attachment saved to Files." : "קובץ מצורף נשמר לקטגוריית קבצים.",
    "Error while saving attachments to Files." : "שגיאה בזמן שמירת קבצים מצורפים לקטגוריית קבצים.",
    "Error while saving attachment to Files." : "שגיאה בזמן שמירת קובץ מצורף לקטגוריית קבצים.",
    "Message flag could not be set." : "לא ניתן היה להגדיר דגל להודעה",
    "Could not move message." : "לא ניתן להעביר את ההודעה.",
    "Invalid account" : "חשבון לא חוקי",
    "Invalid folder" : "תיקייה לא חוקית",
    "Unknown error" : "שגיאה בלתי ידועה",
    "All inboxes" : "כל תיבות דואר נכנס",
    "you" : "את/ה",
    "Send message to {email}" : "שליחת הודעה אל {email}",
    "{from}\n{subject}" : "{from}\n{subject}",
    "Show all folders" : "הצגת כל התיקיות",
    "Collapse folders" : "קיווץ תיקיות",
    "Error while deleting account." : "שגיאה בזמן מחיקת חשבון.",
    "Choose a file to add as attachment" : "בחירת קובץ להוספה כקובץ מצורף",
    "Reply" : "תגובה",
    "Send" : "שליחה",
    "Sending …" : "שולח...",
    "Message sent!" : "הודעה נשלחה!",
    "Server error" : "שגיאת שרת",
    "Opening HTML drafts is not supported yet." : "פתיחת טיוטות HTML לא נתמך עדיין.",
    "No writable calendars found" : "לא נמצאו יומנים ברי כתיבה",
    "Error while importing the calendar event" : "שגיאה בזמן יבוא של אירוע היומן",
    "Error while downloading calendar event" : "שגיאה בזמן הורדת אירוע יומן",
    "& others" : "& אחרים",
    "Error while loading messages." : "שגיאה בזמן העלאת הודעות.",
    "Inbox" : "דואר נכנס",
    "Sent" : "נשלח",
    "Drafts" : "טיוטות",
    "Archive" : "ארכיב",
    "Trash" : "פח אשפה",
    "Junk" : "דואר זבל",
    "All" : "הכל",
    "Favorites" : "מועדפים",
    "Auto detect failed. Please use manual mode." : "איתור אוטומטי נכשל. יש להשתמש במצב ידני.",
    "Creating account failed: " : "יצירת חשבון נכשלה:",
    "Delete permanently" : "מחיקה לצמיתות",
    "Error loading message" : "שגיאה בהעלאת הודעה",
    "Redirect" : "הפנייה",
    "The link leads to %s" : "הקישור מוביל אל %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "אם אינך רוצה לבקר בדף זה, ניתן לחזור אל <a href=\"%s\">הדואר</a>.",
    "Continue to %s" : "ממשיך אל %s",
    "Connect" : "התחברות"
},
"nplurals=2; plural=(n != 1);");
